@@ -30,7 +30,8 @@ BooksWindow::BooksWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
 
-    if (CommonStatic::GeneralSettings(this)->value("license", false).toBool()){
+    QSettings* settings = CommonStatic::GeneralSettings(this);
+    if (settings->value("license", false).toBool()){
         ui->pbnLicense->setVisible(false);
         ui->lblMessage->setText("Books are downloaded from the <a href=\"http://www.projectaon.org/en/Main/Home\">Project AON</a> website\
                                 under the <a href=\"http://www.projectaon.org/en/Main/License\">AON License.</a>");
@@ -38,6 +39,8 @@ BooksWindow::BooksWindow(QWidget *parent) :
         ui->lblMessage->setText("Books are downloaded from the <a href=\"http://www.projectaon.org/en/Main/Home\">Project AON</a> website. <br>\
                                 To downlad the books, you must accept the <a href=\"http://www.projectaon.org/en/Main/License\">AON License</a>.");
     }
+    delete settings;
+
     connect(ui->pbnLicense, SIGNAL(clicked()), this, SLOT(LicenseSlot()));
     connect(ui->pbnUpdate, SIGNAL(clicked()), this, SLOT(UpdateSlot()));
     m_Books = new Books(this);
@@ -130,11 +133,13 @@ void BooksWindow::BuildList()
 
 void BooksWindow::DownloadSlot()
 {
-    if (!CommonStatic::GeneralSettings(this)->value("license", false).toBool()){
+    QSettings* settings = CommonStatic::GeneralSettings(this);
+    if (!settings->value("license", false).toBool()){
         LicenseSlot();
-        if (!CommonStatic::GeneralSettings(this)->value("license", false).toBool())
+        if (!settings->value("license", false).toBool())
             return;
     }
+    delete settings;
 
     QPushButton* pbn = (QPushButton*)sender();
     BookEntry* book = m_Books->List.at(pbn->objectName().toInt());
@@ -153,6 +158,7 @@ void BooksWindow::LicenseSlot()
         QSettings* settings = CommonStatic::GeneralSettings(this);
         settings->setValue("license", true);
         settings->sync();
+        delete settings;
     }
     delete dlg;
 }
