@@ -244,8 +244,11 @@ BookWindow::BookWindow(QWidget *parent) :
     m_ChoiceButtons.append(ui->pbnChoice_5);
     m_ChoiceButtons.append(ui->pbnChoice_6);
     m_ChoiceButtons.append(ui->pbnChoice_7);
-    foreach (QPushButton* pbn, m_ChoiceButtons)
+    QList<QPushButton*>::const_iterator i;
+    for (i = m_ChoiceButtons.constBegin(); i != m_ChoiceButtons.constEnd(); ++i){
+        QPushButton* pbn = *i;
         connect(pbn, SIGNAL(clicked()), SLOT(ChoiceSlot()));
+    }
 
     ui->pbnEnd->setVisible(false);
     ui->pbnFight->setVisible(false);
@@ -324,6 +327,7 @@ void BookWindow::ShowSection(int section)
 
         // Autosave:
         if (newSection){
+            m_StatusButtonEnabled = true;
             bool saved = false;
 
             ui->lblMessage->clear();
@@ -414,7 +418,7 @@ void BookWindow::ShowSectionChoices(int section)
     if (m_Book->Sections.contains(section)){
         m_Section = m_Book->Sections[section];
 
-        ui->pbnInventory->setEnabled(true);
+        ui->pbnInventory->setEnabled(m_StatusButtonEnabled);
         bool enemies = m_Section->GetEnemiesCount() > 0;
         if (enemies){
             ui->pbnFight->setVisible(true);
@@ -487,7 +491,9 @@ void BookWindow::SetChoiceText(QPushButton* button, QString text)
     QStringList words = text.split(" ");
 
     QString line;
-    foreach (QString w, words){
+    QStringList::const_iterator i;
+    for (i = words.constBegin(); i != words.constEnd(); ++i){
+        QString w = *i;
         if (fm.width(line) + fm.width(" ") + fm.width(w) > maxWidth){
             parts.append(line.trimmed());
             line.clear();
@@ -515,7 +521,7 @@ void BookWindow::ExitSection()
         }else{
             if (CommonStatic::ConfirmMessage(this, "Eat", "Do you want to eat now?") == QMessageBox::Yes){
                 for (int i=0; i<m_Section->MustEat; i++){
-                    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseMeal);
+                    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseMeal, false);
                     dlg->exec();
                     Item* m = dlg->SelectedItem();
                     if (m == NULL){
@@ -618,6 +624,7 @@ void BookWindow::FightSlot()
         dlg->setParent(NULL);
 #endif
 #endif
+        dlg->SetBookWindow(this);
         dlg->exec();
         evaded = dlg->HasEvaded();
         delete dlg;
@@ -867,7 +874,7 @@ void BookWindow::show()
 {
     QMainWindow::show();
     if (m_Section)
-        QTimer::singleShot(250, this, SLOT(ShowSectionSlot()));
+        QTimer::singleShot(50, this, SLOT(ShowSectionSlot()));
 }
 
 void BookWindow::ShowSectionSlot()
@@ -894,7 +901,9 @@ void BookWindow::Save(QString filename, Player* player, int book, int section)
 
     settings.beginWriteArray("items");
     int index = 0;
-    foreach(Item* i, player->Items){
+    QList<Item*>::const_iterator iterator;
+    for (iterator = player->Items.constBegin(); iterator != player->Items.constEnd(); ++iterator){
+        Item* i = *iterator;
         settings.setArrayIndex(index);
         if (!i->GetIsWeapon())
             settings.setValue("item", qVariantFromValue(*i));
@@ -906,7 +915,8 @@ void BookWindow::Save(QString filename, Player* player, int book, int section)
 
     settings.beginWriteArray("hiddenitems");
     index = 0;
-    foreach(Item* i, player->HiddenItems){
+    for (iterator = player->HiddenItems.constBegin(); iterator != player->HiddenItems.constEnd(); ++iterator){
+        Item* i = *iterator;
         settings.setArrayIndex(index);
         if (!i->GetIsWeapon())
             settings.setValue("item", qVariantFromValue(*i));
@@ -919,7 +929,9 @@ void BookWindow::Save(QString filename, Player* player, int book, int section)
 
     settings.beginWriteArray("kaidisciplines");
     index = 0;
-    foreach(KaiDiscipline* d, player->KaiDisciplines){
+    QList<KaiDiscipline*>::const_iterator dIterator;
+    for (dIterator = player->KaiDisciplines.constBegin(); dIterator != player->KaiDisciplines.constEnd(); ++dIterator){
+        KaiDiscipline* d = *dIterator;
         settings.setArrayIndex(index);
         settings.setValue("kaidiscipline", d->ToString());
         index++;
@@ -990,8 +1002,16 @@ bool BookWindow::Load(QString filename)
         var = settings.value("item");
         if (var.isValid()){
             Item* i = new Item(var.value<Item>());
+            // Set the UUID:
             if (i->GetUUID().isEmpty())
                 i->SetUUID(QUuid::createUuid().toString());
+
+            // Remove useless descriptions:
+            if (i->Description.endsWith("ENDURANCE points to your total") ||
+                i->Description.endsWith("points to your COMBAT SKILL when used in combat")){
+                i->Description.clear();
+            }
+
             // For compatibility with previously saved positions, check if the item has
             // the CanBeEquipped property
             if ((i->GetIsArmor() || i->GetIsWeapon()) && !i->HasProperty("CanBeEquipped"))
@@ -1229,6 +1249,17 @@ bool BookWindow::Load(QString filename)
         }
     }
 
+    // Check player maximum special items:
+    if (m_Player->SpecialItemsCount() > 12){
+        MessageBox("Special items limit", "The maximum number of special items is now 12.\nYou'll need to drop exceeding items.");
+        while(m_Player->SpecialItemsCount() > 12){
+            QString s = ChooseSpecialItem("Choose a special item to drop.");
+            Item* i = m_Player->GetItem(s);
+            m_Player->RemoveItem(s);
+            if (m_Section)
+                m_Section->AddItem(i);
+        }
+    }
     m_Loaded = true;
     return true;
 }
@@ -1240,49 +1271,43 @@ QString BookWindow::GetBookSaveFilename(int number)
     return filename;
 }
 
-QString BookWindow::ChooseMeal(QString title)
+Item* BookWindow::ChooseItem(int mode, QString message, bool mandatory)
 {
-    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseMeal);
-    dlg->setWindowTitle(title);
-    dlg->SetMessage(title);
+    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, mode, mandatory);
+    dlg->SetMessage(message);
     dlg->exec();
-    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+    return dlg->SelectedItem();
 }
 
-QString BookWindow::ChooseWeapon(QString title)
+QString BookWindow::ChooseMeal(QString title, bool mandatory)
 {
-    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseWeapon);
-    dlg->setWindowTitle(title);
-    dlg->SetMessage(title);
-    dlg->exec();
-    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+    Item* i = ChooseItem(ChooseItemWindow::ChooseMeal, title, mandatory);
+    return i ? i->Name : "";
 }
 
-QString BookWindow::ChooseItem(QString title)
+QString BookWindow::ChooseWeapon(QString title, bool includeSpecial, bool mandatory)
 {
-    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseItem);
-    dlg->setWindowTitle(title);
-    dlg->SetMessage(title);
-    dlg->exec();
-    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+    Item* i = ChooseItem(includeSpecial ? ChooseItemWindow::ChooseWeaponSpecial : ChooseItemWindow::ChooseWeapon,
+                         title, mandatory);
+    return i ? i->Name : "";
 }
 
-QString BookWindow::ChooseItemExceptMeals(QString title)
+QString BookWindow::ChooseItem(QString title, bool mandatory)
 {
-    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseItemExceptMeals);
-    dlg->setWindowTitle(title);
-    dlg->SetMessage(title);
-    dlg->exec();
-    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+    Item* i = ChooseItem(ChooseItemWindow::ChooseItem, title, mandatory);
+    return i ? i->Name : "";
 }
 
-QString BookWindow::ChooseSpecialItem(QString title)
+QString BookWindow::ChooseItemExceptMeals(QString title, bool mandatory)
 {
-    ChooseItemWindow* dlg = new ChooseItemWindow(this, m_Player, ChooseItemWindow::ChooseSpecialItem);
-    dlg->setWindowTitle(title);
-    dlg->SetMessage(title);
-    dlg->exec();
-    return dlg->SelectedItem() ? dlg->SelectedItem()->Name : "";
+    Item* i = ChooseItem(ChooseItemWindow::ChooseItemExceptMeals, title, mandatory);
+    return i ? i->Name : "";
+}
+
+QString BookWindow::ChooseSpecialItem(QString title, bool mandatory)
+{
+    Item* i = ChooseItem(ChooseItemWindow::ChooseSpecialItem, title, mandatory);
+    return i ? i->Name : "";
 }
 
 bool BookWindow::LoadNextBook()
@@ -1402,7 +1427,6 @@ Item* BookWindow::AddHealingPickItem(QString name, int enduranceRestore)
         Item* i = new Item(m_Player);
         i->Name = name;
         i->SetEnduranceRestore(enduranceRestore);
-        i->Description = QString("Restores %1 ENDURANCE POINTS").arg(enduranceRestore);
         m_PickItems.append(i);
         return i;
     }
@@ -1411,7 +1435,7 @@ Item* BookWindow::AddHealingPickItem(QString name, int enduranceRestore)
 
 int BookWindow::PickItems(int max)
 {
-    PickItemsWindow* dlg = new PickItemsWindow(this, m_Player, m_Book->GetSerie(), m_PickGoldCrowns, &m_PickItems, max);
+    PickItemsWindow* dlg = new PickItemsWindow(this, m_Section, m_Player, m_Book->GetSerie(), m_PickGoldCrowns, &m_PickItems, max);
     while (dlg->exec() != QDialog::Accepted	){}
     int picked = dlg->GetPickedItemsCount();
     delete dlg;
@@ -1539,16 +1563,31 @@ void BookWindow::EnableFightButton()
     ui->pbnFight->setEnabled(true);
 }
 
+void BookWindow::DisableStatusButton()
+{
+    ui->pbnInventory->setEnabled(false);
+    m_StatusButtonEnabled = false;
+}
+
+void BookWindow::EnableStatusButton()
+{
+    ui->pbnInventory->setEnabled(true);
+    m_StatusButtonEnabled = true;
+}
+
 void BookWindow::SetVisibleChoiceButtons(int number)
 {
-    foreach (QPushButton* pbn, m_ChoiceButtons){
+    QList<QPushButton*>::const_iterator i;
+    for (i = m_ChoiceButtons.constBegin(); i != m_ChoiceButtons.constEnd(); ++i){
+        QPushButton* pbn = *i;
         pbn->setVisible(false);
         pbn->setEnabled(false);
     }
 
     if (number > 0){
         int index = 0;
-        foreach (QPushButton* pbn, m_ChoiceButtons){
+        for (i = m_ChoiceButtons.constBegin(); i != m_ChoiceButtons.constEnd(); ++i){
+            QPushButton* pbn = *i;
             pbn->setVisible(true);
             if (!m_Section->HasRandomChoices() && m_Section->Choices.count() > index)
                 pbn->setEnabled(m_Section->Choices.at(index)->Enabled);
@@ -1569,3 +1608,49 @@ void BookWindow::ScrollToTopSlot()
 {
     ui->scrollArea->ensureVisible(0, 0, 0, 0);
 }
+
+Item* BookWindow::CreateItem(QString name, bool special)
+{
+    if (!name.isEmpty()){
+        Item* i = new Item(this);
+        i->Name = name;
+        i->SetIsSpecial(special);
+        return i;
+    }
+    return NULL;
+}
+
+void BookWindow::AddItemToPlayer(Item* item, bool mandatory)
+{
+    if (!item)
+        return;
+
+    bool done = true;
+    QString error;
+    while (!m_Player->CanTakeItem(item, &error)){
+        QString message = QString("In order to take the %1 you need to drop a").arg(item->GetName());
+        Item* i = NULL;
+        if (item->GetIsSpecial())
+            i = ChooseItem(ChooseItemWindow::ChooseSpecialItem, message.append(" special item."), mandatory);
+        else if (item->GetIsWeapon())
+            i = ChooseItem(ChooseItemWindow::ChooseWeaponSpecial, message.append(" weapon."), mandatory);
+        else
+            i = ChooseItem(ChooseItemWindow::ChooseItem, message.append(" backpack item."), mandatory);
+
+        if (i){
+            m_Player->Items.removeOne(i);
+            m_Section->AddItem(i);
+        }else if (!mandatory){
+            done = false;
+            break;
+        }
+
+    }
+
+    if (done){
+        m_Player->Items.append(item);
+        item->setParent(m_Player);
+    }else{
+        m_Section->AddItem(item);
+    }
+}
