@@ -41,6 +41,8 @@ public:
     int DeathsCount;
 
     static QString GetRankDescription(int serie, int kaiDisciplinesCount);
+    static int GetRankDisciplines(int serie, QString rank);
+
     QHash<QString, QString> Properties;
     void CheckEndurance();
     void Dump();
@@ -53,12 +55,18 @@ public:
     /** Returns a list of armors currently equipped */
     QList<Armor*> GetEquippedArmors();
 
+    bool CanTakeItem(Item* item, QString* error, int deltaWeapons=0, int deltaItems=0, int deltaSpecial=0, int deltaArrows=0);
+
 private:
     bool m_Backpack;
     bool m_CanHunt;
     bool GetBoolProperty(QString name) { return GetProperty(name).toInt() == 1;}
     void SetBoolProperty(QString name, bool value) { SetProperty(name, value ? "1" : "0"); }
 
+    static QStringList RanksKai;
+    static QStringList RanksMagnakai;
+    static QStringList RanksGrandMaster;
+
 public slots:
     /** Remove all disciplines (used at the beginning of a new serie when disciplines change)
      *  It doesn't removes the disciplines, but set their "serie" to 0 (zero) so they are not
@@ -127,8 +135,12 @@ public slots:
     Item* AddItem(QString name, bool special);
     /** Remove one item from the player, returns true if the item has been removed */
     bool RemoveItem(QString name);
+    /** Remove one item from the player, returns true if the item has been removed */
+    bool RemoveItemByUUID(QString UUID);
     /** Return one item from the player */
     Item* GetItem(QString name);
+    /** Return one item from the player */
+    Item* GetItemByUUID(QString UUID);
 
     /** Adds to the player a meal with the given name */
     Item* AddMeal(QString name);
@@ -243,6 +255,9 @@ public slots:
     void SetNotes(QString value) { SetProperty("Notes", value); }
     /** Appends a line to the action chart's notes*/
     void AppendNotesLine(QString value);    
+
+    /** Returns true if the player has the given rank (or higher)*/
+    bool HasRank(QString);
 };
 
 #endif // PLAYER_H
