@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include <QEventLoop>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 #include "randomnumberpicker.h"
 
@@ -10,7 +11,7 @@ namespace Ui {
     class BetWindow;
 }
 
-class BetWindow : public QMainWindow
+class BetWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -20,20 +21,13 @@ public:
 
     int GetRounds() { return m_Round; }
 
-    void exec();
-
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     Ui::BetWindow *ui;
 
-    bool m_CanClose;
     int m_Bet;
     int m_Value;
     int m_Won;
     Player* m_Player;
-    QEventLoop* m_Loop;
 
     int m_Round;
     int m_Number;
