@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include <QEventLoop>
+#include "controls/dialogwindow.h"
 #include "core/player.h"
 #include "randomnumberpicker.h"
 
@@ -10,7 +11,7 @@ namespace Ui {
     class CartwheelWindow;
 }
 
-class CartwheelWindow : public QMainWindow
+class CartwheelWindow : public DialogWindow
 {
     Q_OBJECT
 
@@ -18,20 +19,13 @@ public:
     explicit CartwheelWindow(QWidget *parent = 0, Player* player=0);
     ~CartwheelWindow();
 
-    void exec();
-
-protected:
-    void closeEvent(QCloseEvent *event);
-
 private:
     Ui::CartwheelWindow *ui;
 
-    bool m_CanClose;
     int m_Bet;
     int m_Value;
     int m_Won;
     Player* m_Player;
-    QEventLoop* m_Loop;
 
     RandomNumberPicker* m_RandomPicker;
 
