@@ -1,13 +1,13 @@
 #ifndef SELECTFROMLISTWINDOW_H
 #define SELECTFROMLISTWINDOW_H
 
-#include <QDialog>
+#include "controls/dialogwindow.h"
 #include <QCheckBox>
 namespace Ui {
 class SelectFromListWindow;
 }
 
-class SelectFromListWindow : public QDialog
+class SelectFromListWindow : public DialogWindow
 {
     Q_OBJECT
     
